Id

Struct Id 

pub struct Id(/* private fields */);
Unique identifier for any entity in the diagram, Cow<'static, str> newtype.

Must begin with a letter or underscore, and contain only letters, numbers, and underscores.

Examples

use disposition_model_common::{id, Id};

let id_compile_time_checked = id!("example_id");
let id_runtime_checked = Id::new("example_id").unwrap();

assert_eq!(id_compile_time_checked, id_runtime_checked);
assert_eq!(id_runtime_checked.as_str(), "example_id");

Implementations

Source

impl Id

pub fn new(s: &'static str) -> Result<Self, IdInvalidFmt<'static>>

Returns a new Id if the given &str is valid.

Most users should use the id! macro as this provides compile time checks and returns a const value.

Source

impl Id

pub fn is_valid_id(proposed_id: &str) -> bool

Returns whether the provided &str is a valid station identifier.

pub fn into_inner(self) -> Cow<'static, str>

Returns the inner Cow<'static, str>.

pub fn as_str(&self) -> &str

Returns the &str held by this ID.